==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridCellEditEndedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridCellEditEndedEventArgsDescription } from "./GridCellEditEndedEventArgsDescription";
/**
 * @hidden
 */
export let GridCellEditEndedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridCellEditEndedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridCellEditEndedEventArgsDescriptionMetadata.a == null) {
                GridCellEditEndedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridCellEditEndedEventArgsDescriptionMetadata.c(GridCellEditEndedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridCellEditEndedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridCellEditEndedEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
            a.item("Row", "Number:int");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            GridCellEditEndedEventArgsDescriptionMetadata.b(a);
            a.ad("GridCellEditEndedEventArgs", () => new GridCellEditEndedEventArgsDescription());
            a.ac("GridCellEditEndedEventArgs", GridCellEditEndedEventArgsDescriptionMetadata.a);
        }
    }
    GridCellEditEndedEventArgsDescriptionMetadata.$t = markType(GridCellEditEndedEventArgsDescriptionMetadata, 'GridCellEditEndedEventArgsDescriptionMetadata');
    GridCellEditEndedEventArgsDescriptionMetadata.a = null;
    return GridCellEditEndedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridCellEditEndedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridCellEditEndedEventArgsDescription } from "./GridCellEditEndedEventArgsDescription";
/**
 * @hidden
 */
export let GridCellEditEndedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridCellEditEndedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridCellEditEndedEventArgsDescriptionMetadata.a == null) {
                GridCellEditEndedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridCellEditEndedEventArgsDescriptionMetadata.c(GridCellEditEndedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridCellEditEndedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridCellEditEndedEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
            a.item("Row", "Number:int");
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        }
        static d(a) {
            GridCellEditEndedEventArgsDescriptionMetadata.b(a);
            a.ae("GridCellEditEndedEventArgs", () => new GridCellEditEndedEventArgsDescription());
            a.ad("GridCellEditEndedEventArgs", GridCellEditEndedEventArgsDescriptionMetadata.a);
        }
    }
    GridCellEditEndedEventArgsDescriptionMetadata.$t = markType(GridCellEditEndedEventArgsDescriptionMetadata, 'GridCellEditEndedEventArgsDescriptionMetadata');
    GridCellEditEndedEventArgsDescriptionMetadata.a = null;
    return GridCellEditEndedEventArgsDescriptionMetadata;
})();
